# Workflow References

### `build_nomad_workflow()`
::: nomad_utility_workflows.utils.workflows.build_nomad_workflow

### `nodes_to_graph()`
::: nomad_utility_workflows.utils.workflows.nodes_to_graph

### NodeAttributes
::: nomad_utility_workflows.utils.workflows.NodeAttributes
